@@ -1,5 +1,7 @@
 from typing import List, Optional, Tuple, Dict, Callable, Any
 from functools import reduce
+import os
+import os
 from pathlib import Path
 import re
 from .utils import maybe_is_text, maybe_is_truncated
@@ -12,10 +14,12 @@ from langchain.llms import OpenAI
 from langchain.llms.base import LLM
 from langchain.chains import LLMChain
 from langchain.callbacks import get_openai_callback
-from langchain.cache import InMemoryCache
+from langchain.cache import SQLiteCache
 import langchain
 
-langchain.llm_cache = InMemoryCache()
+CACHE_PATH = Path.home() / ".paperqa" / "llm_cache.db"
+os.makedirs(os.path.dirname(CACHE_PATH), exist_ok=True)
+langchain.llm_cache = SQLiteCache(CACHE_PATH)
 
 
 @dataclass
@@ -227,7 +231,7 @@ class Docs:
                 ),
                 doc.page_content,
             )
-            if "Not applicable" not in c[-1]:
+            if "Not applicable" not in c[2]:
                 answer.contexts.append(c)
                 yield answer
             if len(answer.contexts) == max_sources:
